@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.09';
+our $VERSION = '2.38';
 
 use parent 'Class::Singleton', 'DateTime::TimeZone::OffsetOnly';
 
@@ -59,7 +59,7 @@ DateTime::TimeZone::Floating - A time zone that is always local
 
 =head1 VERSION
 
-version 2.09
+version 2.38
 
 =head1 SYNOPSIS
 
@@ -73,25 +73,32 @@ A floating time has no time zone, and has an effective offset of zero.
 
 =head1 USAGE
 
-This class has the same methods as a real time zone object, but the
-C<short_name_for_datetime()>, and C<category()> methods both return
-undef.
+This class has the same methods as a real time zone object. The
+C<short_name_for_datetime()> method returns the string "floating" and the
+C<category()> method returns C<undef>.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for DateTime-TimeZone can be found at L<https://github.com/houseabsolute/DateTime-TimeZone>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dave Rolsky.
+This software is copyright (c) 2019 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
