@@ -4,8 +4,9 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.23';
+our $VERSION = '2.38';
 
+use DateTime::Duration;
 use DateTime::TimeZone::OlsonDB::Rule;
 use DateTime::TimeZone::OlsonDB::Zone;
 
@@ -178,7 +179,7 @@ sub rules_by_name {
 sub parse_day_spec {
     my ( $day, $month, $year ) = @_;
 
-    return $day if $day =~ /^\d+$/;
+    return ( $month, $day ) if $day =~ /^\d+$/;
 
     if ( $day =~ /^last(\w\w\w)$/ ) {
         my $dow = $DAYS{$1};
@@ -200,7 +201,7 @@ sub parse_day_spec {
             $dt -= $PLUS_ONE_DAY_DUR;
         }
 
-        return $dt->day;
+        return ( $dt->month, $dt->day );
     }
     elsif ( $day =~ /^(\w\w\w)([><])=(\d\d?)$/ ) {
         my $dow = $DAYS{$1};
@@ -218,7 +219,7 @@ sub parse_day_spec {
             $dt += $dur;
         }
 
-        return $dt->day;
+        return ( $dt->month, $dt->day );
     }
     else {
         die "Invalid on spec for rule: $day\n";
@@ -300,7 +301,7 @@ DateTime::TimeZone::OlsonDB - An object to represent an Olson time zone database
 
 =head1 VERSION
 
-version 2.23
+version 2.38
 
 =head1 SYNOPSIS
 
@@ -349,7 +350,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Dave Rolsky.
+This software is copyright (c) 2019 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
